@@ -19,6 +19,31 @@ from .symbols import Variable, Equation, Shock, Parameter, TSymbol
 from sympy.matrices import Matrix, zeros
 
 
+def crawl_cached_models(mtxt, ftxt):
+
+    global cached_models
+
+    processed_raw_model = None
+
+    if "cached_models" in globals():
+
+        for i in cached_models:
+
+            use_cached = cached_models[i].fdict["yaml_raw"] == mtxt
+
+            if ftxt is not None:
+                use_cached &= cached_models[i].fdict.get("ffile_raw") == ftxt
+
+            if use_cached:
+                processed_raw_model = cached_models[i]
+                break
+
+    else:
+        cached_models = {}
+
+    return processed_raw_model
+
+
 class DSGE(DSGE_RAW):
     """Base class. Every model is an instance of the DSGE class and inherents its methods."""
 
@@ -76,7 +101,6 @@ class DSGE(DSGE_RAW):
     def variables(self):
         return self["var_ordering"]
 
-    # ->
     @property
     def const_var(self):
         return self["const_var"]
@@ -85,8 +109,6 @@ class DSGE(DSGE_RAW):
     def const_eq(self):
         return self["const_eq"]
 
-    # <-
-
     @property
     def parameters(self):
         return self["par_ordering"]
@@ -342,10 +364,10 @@ class DSGE(DSGE_RAW):
             [self.parameters], [ss[str(px)] for px in self["other_para"]]
         )  # , modules=context_f)
 
-        def compile(px):
+        def pcompile(px):
             return list(px) + psi(list(px))
 
-        self.pcompile = compile
+        self.pcompile = pcompile
         self.parafunc = [p.name for p in self["other_para"]], psi
         self.psi = psi
         self.PSI = PSI
@@ -376,7 +398,7 @@ class DSGE(DSGE_RAW):
             Path to the `*.yaml` file.
         """
 
-        global processed_raw_model
+        global cached_models
 
         if verbose:
             st = time.time()
@@ -385,21 +407,17 @@ class DSGE(DSGE_RAW):
         mtxt = f.read()
         f.close()
 
-        use_cached = False
+        func_file = mfile[:-5] + "_funcs.py"
 
-        if "processed_raw_model" in globals():
+        if os.path.exists(func_file):
+            ff = open(func_file)
+            ftxt = ff.read()
+        else:
+            ftxt = None
 
-            use_cached = True
-            func_file = mfile[:-5] + "_funcs.py"
+        processed_raw_model = crawl_cached_models(mtxt, ftxt)
 
-            if os.path.exists(func_file):
-                ff = open(func_file)
-                ftxt = ff.read()
-                use_cached &= processed_raw_model.fdict.get("ffile_raw") == ftxt
-
-            use_cached &= processed_raw_model.fdict["yaml_raw"] == mtxt
-
-        if use_cached:
+        if processed_raw_model is not None:
             pmodel = deepcopy(processed_raw_model)
 
         else:
@@ -427,7 +445,7 @@ class DSGE(DSGE_RAW):
                     + " Parallelization disabled under Windows and Mac due to a problem with pickling some of the symbolic elements. Sorry..."
                 )
 
-            processed_raw_model = deepcopy(pmodel)
+            cached_models[len(cached_models)] = deepcopy(pmodel)
 
         if verbose:
             duration = np.round(time.time() - st, 3)
@@ -444,7 +462,7 @@ class DSGE(DSGE_RAW):
     @classmethod
     def load(cls, npzfile, force_parse=False, verbose=False):
 
-        global processed_raw_model
+        global cached_models
 
         if verbose:
             st = time.time()
@@ -452,6 +470,7 @@ class DSGE(DSGE_RAW):
         fdict = dict(np.load(npzfile, allow_pickle=True))
 
         mtxt = str(fdict["yaml_raw"])
+        ftxt = str(fdict.get("ffile_raw"))
 
         try:
             if force_parse:
@@ -460,13 +479,12 @@ class DSGE(DSGE_RAW):
             # pickling errors across protocols are likely
             # so this is a test:
             pmodel_dump = cpickle.dumps(pmodel, protocol=4)
+
         except:
-            use_cached = False
 
-            if "processed_raw_model" in globals():
-                use_cached = processed_raw_model.fdict["yaml_raw"] == mtxt
+            processed_raw_model = crawl_cached_models(mtxt, ftxt)
 
-            if use_cached:
+            if processed_raw_model is not None:
                 pmodel = deepcopy(processed_raw_model)
             else:
                 import tempfile
@@ -522,6 +540,10 @@ class DSGE(DSGE_RAW):
         mtxt = mtxt.replace("^", "**")
         mtxt = mtxt.replace(";", "")
         mtxt = re.sub(r"@ ?\n", " ", mtxt)
+        # try to detect if `~` wants to be a `-`
+        mtxt = mtxt.replace("\n ~ ", "\n - ")
+        mtxt = mtxt.replace("\n  ~ ", "\n  - ")
+        mtxt = mtxt.replace("   ~ ", "   - ")
         model_yaml = yaml.safe_load(mtxt)
 
         dec = model_yaml["declarations"]
@@ -550,16 +572,22 @@ class DSGE(DSGE_RAW):
             observables = []
             obs_equations = dict()
 
-        if "constrained" in dec:
-            c_var = Variable(dec["constrained"][0])
-            # only one constraint allowed
+        if "constraint" in model_yaml["equations"]:
+
+            if len(model_yaml["equations"]["constraint"]) > 1:
+                raise NotImplementedError("Only one constraint allowed.")
+
             raw_const = model_yaml["equations"]["constraint"][0]
 
-            if "=" in raw_const:
+            try:
                 lhs, rhs = str.split(raw_const, "=")
-            else:
-                lhs, rhs = raw_const, "0"
+                assert not " " in lhs.strip()
+            except:
+                raise SyntaxError(
+                    "constraint is supposed to have the form `constrained_variable = equation`"
+                )
 
+            c_var = Variable(lhs.strip())
             try:
                 lhs = eval(lhs, context)
                 rhs = eval(rhs, context)
@@ -609,7 +637,11 @@ class DSGE(DSGE_RAW):
 
             try:
                 lhs = eval(lhs, context)
+                if isinstance(lhs, (int, float)):
+                    lhs = sympy.sympify(lhs)
                 rhs = eval(rhs, context)
+                if isinstance(rhs, (int, float)):
+                    rhs = sympy.sympify(rhs)
             except TypeError as e:
                 raise SyntaxError(
                     "While parsing %s, got this error: %s" % (eq, repr(e))
